## {{page-title}}

List of Profiles
The links to the Profiles that have been defined for this implementation guide are listed hereafter.

Allergy Intolerance (IPS)
This profile represents the constraints applied to the AllergyIntolerance resource by the International Patient Summary (IPS) FHIR Implementation Guide. A record of an allergy or intolerance is represented in the patient summary as an instance of an AllergyIntolerance resource constrained by this profile.

It documents the relevant allergies or intolerances (conditions) for a patient, describing the kind of reaction (e.g. rash, anaphylaxis,..); preferably the agents that cause it; and optionally the criticality and the certainty of the allergy.

Composition (IPS)
Clinical document used to represent the International Patient Summary (IPS) data set. An International Patient Summary (IPS) document is an electronic health record extract containing essential healthcare information about a subject of care. The IPS dataset is minimal and non-exhaustive; specialty-agnostic and condition-independent; but still clinically relevant. As specified in EN 17269 and ISO/DIS 27269, it is designed for supporting the use case scenario for ‘unplanned, cross border care’, but it is not limited to it. It is intended to be international, i.e., to provide generic solutions for global application beyond a particular region or country.

This profile is based on the ClinicalDocument profile.

Condition (IPS)
This profile represents the constraints applied to the Condition resource by the International Patient Summary (IPS) FHIR Implementation Guide. A record of a problem is represented in the patient summary as an instance of the Condition resource constrained by this profile.

Device (IPS)
This profile represents the constraints applied to the Device resource by the International Patient Summary (IPS) FHIR Implementation Guide, based on FHIR R4. A device used by or implanted on the patient is described in the patient summary as an instance of a Device resource constrained by this profile.

Device (performer, observer)
This profile represents the constraints applied to the Device resource by the IPS project, which specifies an international patient summary based on the FHIR standard R4.;

This profile describes a device that plays the role of observer or performer.

Device Use Statement (IPS)
This profile represents the constraints applied to the DeviceUseStatement resource by the International Patient Summary (IPS) FHIR Implementation Guide, based on FHIR R4. A statement about a device used by or implanted on the patient is described in the patient summary as an instance of a DeviceUseStatement resource constrained by this profile.

DiagnosticReport (IPS)
This profile constrains the DiagnosticReport resource to represent diagnostic test and procedure reports in a patient summary.

Imaging Study (IPS)
This profile represents the constraints applied to the ImagingStudy resource by the IPS project, which specifies the information on a DICOM imaging study this imaging result is part of.

Immunization (IPS)
This profile represents the constraints applied to the Immunization resource by the International Patient Summary (IPS) FHIR Implementation Guide. A record of an immunization is represented in the patient summary as an instance of an Immunization resource constrained by this profile.

It describes the event of a patient being administered a vaccination or a record of a vaccination as reported by a patient, a clinician or another party.

Media observation (Results: laboratory, media)
This profile constrains the Media resource (which is a specialized observation).

Medication (IPS)
This profile represents the constraints applied to the Medication resource by the International Patient Summary (IPS) FHIR Implementation Guide, based on FHIR R4. A medication is described in the patient summary as an instance of a Medication resource constrained by this profile.

Medication Statement (IPS)
This profile represents the constraints applied to the MedicationStatement resource by the International Patient Summary (IPS) FHIR Implementation Guide, based on FHIR R4. A record of a medication statement is represented in the patient summary as an instance of a MedicationStatement resource constrained by this profile.

Observation (Pregnancy: EDD)
This profile constrains the Observation resource to represent the pregnancy expected delivery date.

Observation (Pregnancy: outcome)
This profile constrains the Observation resource to represent the history of pregnancy outcomes (summary).

Observation (Pregnancy: status)
This profile constrains the Observation resource to represent the pregnancy status.

Observation (SH: alcohol use)
This profile constrains the Observation resource to represent alcohol use assessment in a patient summary.

Observation (SH: tobacco use)
This profile constrains the Observation resource to represent Tobacco use assessment in a patient summary.

Observation Results (IPS)
This profile constrains the Observation resource to represent various types of results and associated observations in a patient summary. This is the base profile from which the other results profiles are derived.

Observation Results: laboratory (IPS)
This profile constrains the Observation resource to represent results produced by laboratory tests or panels/studies in a patient summary.

This observation may represent the result of a simple laboratory test such as hematocrit or it may group the set of results produced by a multi-test study or panel such as a complete blood count, a dynamic function test, a urine specimen study. In the latter case, the observation carries the overall conclusion of the study and or a global interpretation by the producer of the study, in the comment element; and references the atomic results of the study as "has-member" child observations.

Observation Results: pathology (IPS)
This profile constrains the Observation resource to represent results produced by pathology studies in a patient summary.

Observation Results: radiology (IPS)
This profile represents the constraints applied to the Observation resource by the IPS project, which specifies a radiology observation for the international patient summary based on the FHIR standard R4.

This observation may represent the conclusions of a diagnostic procedure such a Chest RX, or it may group the set of results produced by that single or multi-modality procedure.

In the latter case, the main observation (this one) carries the overall conclusion of the study and/or a global interpretation by the observer of the study as value of this observation; and may references the atomic results of the study as "child observations".

It allows also providing details about the related study using the partOf element referring to an ImagingStudy resource.

Organization (IPS)
This profile constrains the Organization resource to represent an organization that acts as performer or observer for a result observation (laboratory, pathology or imaging), or as performer for a procedure.

Patient (IPS)
This profile represents the constraints applied to the Patient resource by the International Patient Summary (IPS) FHIR Implementation Guide and describes the minimum expectations for the Patient resource when used in the IPS composition or in one of the referred resources.

Practitioner (IPS)
This profile constrains the practitioner resource to represent a practitioner acting as observer for these imaging results.

PractitionerRole (IPS)
This profile constrains the PractitionerRole resource to represent a practitioner acting as observer for observattion results for a specified organization.

Procedure (IPS)
This profile represents the constraints applied to the Procedure resource by the IPS project, which specifies an entry of the History of Procedure for the international patient summary based on the FHIR standard R4.

Specimen (IPS)
This profile constrains the Specimen resource to represent the characteristics of a biological specimens in the context of laboratory results integrated to a patient summary.
